[−][src]Crate third_wheel
third-wheel is a TLS man-in-the-middle proxy library. Using the crate allows
you to intercept, re-route, modify etc. in-flight HTTP requests and responses
between clients and servers. Client code just needs to provide a struct that impl's
MitmLayer. Examples use cases can be found as binaries in the crate.
Structs
| CertificateAuthority | A certificate authority to use for impersonating websites during the man-in-the-middle. |
Enums
| RequestCapture | Action taken by |
| ResponseCapture | Action taken by |
Traits
| MitmLayer | Capture requests and responses in flight, modify them, intercept them or whatever is required. |
Functions
| create_signed_certificate_for_domain | Sign a certificate for this domain |
| start_mitm | Run a man-in-the-middle TLS proxy |
Type Definitions
| SafeResult | A poorly named result type. This will be replaced in https://github.com/campbellC/third-wheel/issues/17 |