[][src]Enum third_wheel::RequestCapture

pub enum RequestCapture {
    CircumventedResponse(Response<Vec<u8>>),
    ModifiedRequest(Request<Vec<u8>>),
    Continue,
}

Action taken by MitmLayer on intercepting an outgoing request

Variants

CircumventedResponse(Response<Vec<u8>>)

In the case the mitm should not send the request to the domain. Note the TLS handshake will have already taken place

ModifiedRequest(Request<Vec<u8>>)

This request will be sent in place of the client's original request

Continue

Use in the case the mitm should send the original request