[−][src]Enum third_wheel::RequestCapture
Action taken by MitmLayer on intercepting an outgoing request
Variants
In the case the mitm should not send the request to the domain. Note the TLS handshake will have already taken place
This request will be sent in place of the client's original request
Use in the case the mitm should send the original request